@@ -46,11 +46,13 @@
 //!
 //! Perchance does NOT guarantee the same random number generator across new versions of the crate.
 #![cfg_attr(not(feature = "std"), no_std)]
-#![warn(rust_2018_idioms, clippy::all, clippy::needless_pass_by_value)]
-#![allow(clippy::disallowed_types)] // allow usage of std::sync::Mutex (instead of parking_lot) as this is typically intended for WASM
+#![allow(clippy::disallowed_types)] // allow usage of std::sync::Mutex (instead of parking_lot) as this is typically intended for Wasm
 
-use core::ops::{Bound, RangeBounds};
-use macaw::{BoundingBox, Vec2, Vec3};
+use core::ops::Bound;
+use core::ops::RangeBounds;
+use macaw::BoundingBox;
+use macaw::Vec2;
+use macaw::Vec3;
 
 /// The raw random number generator.
 /// As of may 2020, this is the same generator used by `rand::SmallRng`.
@@ -403,7 +405,7 @@ impl PerchanceContext {
 
     /// Like [`Self::weighted_choice_f32`], but returns a sampler that allows you to much more efficiently sample multiple choices with the same weights.
     ///
-    /// Comlexity for `N` samples with `C` weights is `C + N*log(C)` instead of `C + N*C` when using `weighted_choice_f32`.
+    /// Complexity for `N` samples with `C` weights is `C + N*log(C)` instead of `C + N*C` when using `weighted_choice_f32`.
     ///
     /// Panics if given a NaN weight.
     #[cfg(feature = "std")]
@@ -452,9 +454,14 @@ mod global_ctx {
     use super::*;
     use once_cell::sync::Lazy;
     use std::sync::Mutex;
-    use std::time::{SystemTime, UNIX_EPOCH};
+    #[cfg(not(target_family = "wasm"))]
+    use std::time::SystemTime;
+    #[cfg(not(target_family = "wasm"))]
+    use std::time::UNIX_EPOCH;
 
+    #[cfg(not(target_family = "wasm"))]
     const TWO_POW_64: u128 = 2u128.pow(64);
+    #[cfg(not(target_family = "wasm"))]
     const TWO_POW_96: u128 = 2u128.pow(96);
 
     static GLOBAL_RNG: Lazy<Mutex<PerchanceContext>> =
@@ -485,7 +492,7 @@ mod global_ctx {
 
     /// Generates a seed that may be passed to [`perchance::seed_global`](self::seed_global) based on the
     /// system clock.
-    #[cfg(not(wasm))]
+    #[cfg(not(target_family = "wasm"))]
     pub fn gen_time_seed() -> u128 {
         SystemTime::now()
             .duration_since(UNIX_EPOCH)
